@@ -26,18 +26,15 @@ class node(element, anchored):
         anchored.__init__(self)
         element.__init__(self, *args, **kwargs)
 
-    def attach(self, node_obj, edge_set=None, as_outbound=True,
-               as_bidirected=False):
+    def attach(self, node_obj, edge_set=None, as_outbound=True, as_bidirected=False):
         """
         Generalized attach function for attaching nodes with edges
         """
-        if(edge_set is None):
-            edge_set = [edge(m_id=self._m_id, h=self._h,
-                             kind='edge', name='generic')]
+        if edge_set is None:
+            edge_set = [edge(m_id=self._m_id, h=self._h, kind="edge", name="generic")]
         link_order = [self, node_obj] if as_outbound else [node_obj, self]
         for e in edge_set:
-            if(not e.set_from_node(link_order[0]) or
-               not e.set_to_node(link_order[1])):
+            if not e.set_from_node(link_order[0]) or not e.set_to_node(link_order[1]):
                 # Node not found error logged in set node function
                 return []
             e.set_bidirected(as_bidirected)
@@ -70,31 +67,38 @@ class node(element, anchored):
         """
         return self.attach(node_obj, edge_set, as_bidirected=True)
 
-    def detach(self, node_obj, edge_set=None, as_outbound=True,
-               as_bidirected=False, ignore_direction=False, silent=True):
+    def detach(
+        self,
+        node_obj,
+        edge_set=None,
+        as_outbound=True,
+        as_bidirected=False,
+        ignore_direction=False,
+        silent=True,
+    ):
         """
         Generalized detach function for detaching nodes with edges
         """
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.attached_edges(node_obj)
         link_order = [self, node_obj] if as_outbound else [node_obj, self]
         num_detached = 0
         for e in edge_set:
             # validate edge connection exists
-            if(not e.connects(link_order[0], link_order[1],
-                              ignore_direction=ignore_direction)):
-                if(not silent):
+            if not e.connects(
+                link_order[0], link_order[1], ignore_direction=ignore_direction
+            ):
+                if not silent:
                     logger.warning(
                         str(
                             f"{e} does not connect "
-                            f"{link_order[0]} to {link_order[1]}")
+                            f"{link_order[0]} to {link_order[1]}"
+                        )
                     )
                 continue
-            if(as_bidirected and not ignore_direction
-               and not e.is_bidirected()):
-                if(not silent):
-                    logger.warning(
-                        str(f"{e} is not a bidirected edge "))
+            if as_bidirected and not ignore_direction and not e.is_bidirected():
+                if not silent:
+                    logger.warning(str(f"{e} is not a bidirected edge "))
                 continue
             # destroy edge
             num_detached += 1
@@ -142,9 +146,9 @@ class node(element, anchored):
         Destroys attached node and all relevant edges
         Node and all edges are destroyed if edge_set empty
         """
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.outbound_edges(node_obj)
-        if(self.detach_outbound(node_obj, edge_set)):
+        if self.detach_outbound(node_obj, edge_set):
             node_obj.destroy()
 
     def destroy_inbound(self, node_obj, edge_set=None):
@@ -152,9 +156,9 @@ class node(element, anchored):
         Destroys attached node and all relevant edges
         Node and all edges are destroyed if edge_set empty
         """
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.inbound_edges(node_obj)
-        if(self.detach_inbound(node_obj, edge_set)):
+        if self.detach_inbound(node_obj, edge_set):
             node_obj.destroy()
 
     def destroy_bidirected(self, node_obj, edge_set=None):
@@ -162,9 +166,9 @@ class node(element, anchored):
         Destroys attached node and all relevant edges
         Node and all edges are destroyed if edge_set empty
         """
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.bidirected_edges(node_obj)
-        if(self.detach_bidirected(node_obj, edge_set)):
+        if self.detach_bidirected(node_obj, edge_set):
             node_obj.destroy()
 
     def is_attached_out(self, node_obj, edge_set=None):
@@ -172,11 +176,11 @@ class node(element, anchored):
         Tests whether edges attach to a node
         """
         out_set = self.outbound_edges(node_obj)
-        if(edge_set is None):
+        if edge_set is None:
             return len(out_set)
         else:
             for e in edge_set:
-                if(e not in out_set):
+                if e not in out_set:
                     return False
         return True
 
@@ -185,11 +189,11 @@ class node(element, anchored):
         Tests whether edges attach from a node
         """
         in_set = self.inbound_edges(node_obj)
-        if(edge_set is None):
+        if edge_set is None:
             return len(in_set)
         else:
             for e in edge_set:
-                if(e not in in_set):
+                if e not in in_set:
                     return False
         return True
 
@@ -198,11 +202,11 @@ class node(element, anchored):
         Tests whether edges attach either to or from a node
         """
         bi_set = self.bidirected_edges(node_obj)
-        if(edge_set is None):
+        if edge_set is None:
             return len(bi_set)
         else:
             for e in edge_set:
-                if(e not in bi_set):
+                if e not in bi_set:
                     return False
         return True
 
@@ -210,7 +214,7 @@ class node(element, anchored):
         """Returns list of all edges out of node"""
         edge_set = []
         for e in self.edge_ids.obj_list():
-            if(not e.is_bidirected() and e.connects(self, node_obj)):
+            if not e.is_bidirected() and e.connects(self, node_obj):
                 edge_set.append(e)
         return edge_set
 
@@ -218,7 +222,7 @@ class node(element, anchored):
         """Returns list of all edges in to node"""
         edge_set = []
         for e in self.edge_ids.obj_list():
-            if(not e.is_bidirected() and e.connects(node_obj, self)):
+            if not e.is_bidirected() and e.connects(node_obj, self):
                 edge_set.append(e)
         return edge_set
 
@@ -226,7 +230,7 @@ class node(element, anchored):
         """Returns list of all edges between nodes"""
         edge_set = []
         for e in self.edge_ids.obj_list():
-            if(e.is_bidirected() and e.connects(self, node_obj)):
+            if e.is_bidirected() and e.connects(self, node_obj):
                 edge_set.append(e)
         return edge_set
 
@@ -237,42 +241,42 @@ class node(element, anchored):
         silent is used to indicate whther the edge is intened to be used.
         (effectively turns off error checking when false)
         """
-        edge_set = self.outbound_edges(node_obj) + \
-            self.inbound_edges(node_obj) + \
-            self.bidirected_edges(node_obj)
-        if(not silent and edge_set is None):
-            logger.error(
-                str(f"No edges found between {self} and {node_obj}")
-            )
+        edge_set = (
+            self.outbound_edges(node_obj)
+            + self.inbound_edges(node_obj)
+            + self.bidirected_edges(node_obj)
+        )
+        if not silent and edge_set is None:
+            logger.error(str(f"No edges found between {self} and {node_obj}"))
         return edge_set
 
     def outbound_nodes(self, edge_set=None):
         """Returns list of all nodes connected by edges out"""
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.edge_ids.obj_list()
         ret_list = []
         for e in edge_set:
-            if (not e.is_bidirected() and e.connects(source=self)):
+            if not e.is_bidirected() and e.connects(source=self):
                 ret_list.append(e.to_node())
         return ret_list
 
     def inbound_nodes(self, edge_set=None):
         """Returns list of all nodes connected by edges in"""
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.edge_ids.obj_list()
         ret_list = []
         for e in edge_set:
-            if (not e.is_bidirected() and e.connects(target=self)):
+            if not e.is_bidirected() and e.connects(target=self):
                 ret_list.append(e.from_node())
         return ret_list
 
     def bidirected_nodes(self, edge_set=None):
         """Returns list of all nodes connected by edges"""
-        if(edge_set is None):
+        if edge_set is None:
             edge_set = self.edge_ids.obj_list()
         ret_list = []
         for e in edge_set:
-            if (e.is_bidirected()):
+            if e.is_bidirected():
                 ret_list.append(e.opposing_node(self))
         return ret_list
 
@@ -287,11 +291,13 @@ class node(element, anchored):
     def dimension_matches(self, node_obj, silent=True):
         """Test if dimension matches another node"""
         matches = self.dimension == node_obj.dimension
-        if(not matches and not silent):
+        if not matches and not silent:
             logger.error(
-                str("'{}' cant connect to '{}' - dim mismatch {}->{}".
-                    format(self, node_obj, self.dimension,
-                           node_obj.dimension))
+                str(
+                    "'{}' cant connect to '{}' - dim mismatch {}->{}".format(
+                        self, node_obj, self.dimension, node_obj.dimension
+                    )
+                )
             )
         return matches
 
@@ -300,10 +306,13 @@ class node(element, anchored):
         Adds node to higher dimension node and does relevant checks
         """
         # check if valid inclusion
-        if(node_obj.dimension != self.dimension+1):
+        if node_obj.dimension != self.dimension + 1:
             logger.error(
-                str("'{}' cant be member to '{}' - dimension mismatch {}->{}".
-                    format(self, node_obj, self.dimension, node_obj.dimension))
+                str(
+                    "'{}' cant be member to '{}' - dimension mismatch {}->{}".format(
+                        self, node_obj, self.dimension, node_obj.dimension
+                    )
+                )
             )
         # adds self to hdgd and hdgd to list of owners
         else:
@@ -327,10 +336,10 @@ class node(element, anchored):
 
     def set_context(self, ctx, arch=None):
         """Assign values to context fields of node, arch is node architype"""
-        if(arch is None):
+        if arch is None:
             arch = self
         for i in ctx.keys():
-            if (i not in arch.context.keys()):
+            if i not in arch.context.keys():
                 logger.warning(str(f"{i} not a context member of {self}"))
                 continue
             else:
@@ -349,22 +358,22 @@ class node(element, anchored):
         """
         DOT representation
         """
-        if(node_map is None):
-            nid = f'{uuid.UUID(self.jid).hex}'
+        if node_map is None:
+            nid = f"{uuid.UUID(self.jid).hex}"
         else:
-            nid = f'{node_map.index(self.jid)}'
+            nid = f"{node_map.index(self.jid)}"
 
         dstr = f'"n{nid}" [ id="{uuid.UUID(self.jid).hex}", '
         dstr += f'label="n{nid}:{self.name}" '
 
         node_dict = self.context
 
-        if (node_dict):
+        if node_dict:
             for k, v in node_dict.items():
-                if(not isinstance(v, str) or v == ""):
+                if not isinstance(v, str) or v == "":
                     continue
                 dstr += f', {k}="{v[:32]}"'
 
-        dstr += ' ]'
+        dstr += " ]"
 
-        return dstr+'\n'
+        return dstr + "\n"
