@@ -818,10 +818,8 @@ class interp(machine_state):
         if len(kid) > 1:
             kind = atom_res.value.kind
             name = kid[1].token_text()
-            if name in base_arch.super_archs:
-                return self.parent().arch_ids.get_obj_by_name(
-                    name=kid[1].token_text(), kind=kind
-                )
+            if name in base_arch.derived_types():
+                return self.parent().arch_ids.get_obj_by_name(name=name, kind=kind)
             else:
                 self.rt_error(f"{name} is not a super arch of {base_arch.name}")
                 return None
@@ -1038,6 +1036,8 @@ class interp(machine_state):
             try:
                 if op == "reverse":
                     result = jac_value(self, value=atom_res.value.reverse())
+                elif op == "reversed":
+                    result = jac_value(self, value=list(reversed(atom_res.value)))
                 elif op == "copy":
                     result = jac_value(self, value=atom_res.value.copy())
                 elif op == "sort":
@@ -1204,7 +1204,7 @@ class interp(machine_state):
             result = jac_set()
             if len(kid) > 1:
                 for i in self.viable_nodes().obj_list():
-                    if i.name == kid[2].token_text():
+                    if self.get_arch_for(i).is_instance(kid[2].token_text()):
                         result.add_obj(i)
             else:
                 result += self.viable_nodes()
@@ -1262,7 +1262,9 @@ class interp(machine_state):
         for i in (
             self.current_node.outbound_edges() + self.current_node.bidirected_edges()
         ):
-            if len(kid) > 2 and i.name != kid[2].token_text():
+            if len(kid) > 2 and not self.get_arch_for(i).is_instance(
+                kid[2].token_text()
+            ):
                 continue
             result.add_obj(i)
         if len(kid) > 2 and kid[3].name == "filter_ctx":
@@ -1282,7 +1284,9 @@ class interp(machine_state):
         for i in (
             self.current_node.inbound_edges() + self.current_node.bidirected_edges()
         ):
-            if len(kid) > 2 and i.name != kid[2].token_text():
+            if len(kid) > 2 and not self.get_arch_for(i).is_instance(
+                kid[2].token_text()
+            ):
                 continue
             result.add_obj(i)
         if len(kid) > 2 and kid[3].name == "filter_ctx":
@@ -1301,7 +1305,9 @@ class interp(machine_state):
         kid = self.set_cur_ast(jac_ast)
         result = jac_set()
         for i in self.current_node.attached_edges():
-            if len(kid) > 2 and i.name != kid[2].token_text():
+            if len(kid) > 2 and not self.get_arch_for(i).is_instance(
+                kid[2].token_text()
+            ):
                 continue
             result.add_obj(i)
         if len(kid) > 2 and kid[3].name == "filter_ctx":
