@@ -9,6 +9,7 @@ from jaseci.jac.interpreter.interp import interp
 from jaseci.jac.jac_set import jac_set
 from jaseci.jac.machine.jac_scope import jac_scope
 from jaseci.jac.ir.jac_code import jac_ir_to_ast
+from jaseci.utils.id_list import id_list
 
 
 class walker_interp(interp):
@@ -40,10 +41,11 @@ class walker_interp(interp):
                 if i.name == "attr_stmt":
                     self.run_attr_stmt(jac_ast=i, obj=self)
 
-        arch = self.get_arch_for(self.current_node)
-        self.auto_trigger_node_actions(
-            nd=self.current_node, act_list=arch.entry_action_ids
-        )
+        archs = self.get_arch_for(self.current_node).arch_with_supers()
+        act_list = id_list(self)
+        for i in archs:
+            act_list += i.entry_action_ids
+        self.auto_trigger_node_actions(nd=self.current_node, act_list=act_list)
 
         for i in kid:
             if i.name == "walk_entry_block":
@@ -56,10 +58,11 @@ class walker_interp(interp):
                 self.run_walk_exit_block(i)
 
         # self.trigger_activity_actions()
-        arch = self.get_arch_for(self.current_node)
-        self.auto_trigger_node_actions(
-            nd=self.current_node, act_list=arch.exit_action_ids
-        )
+        archs = self.get_arch_for(self.current_node).arch_with_supers()
+        act_list = id_list(self)
+        for i in archs:
+            act_list += i.exit_action_ids
+        self.auto_trigger_node_actions(nd=self.current_node, act_list=act_list)
 
     def run_node_ctx_block(self, jac_ast):
         """
@@ -67,7 +70,7 @@ class walker_interp(interp):
         """
         kid = self.set_cur_ast(jac_ast)
         for i in self.run_name_list(kid[0]):
-            if self.current_node.name == i:
+            if self.get_arch_for(self.current_node).is_instance(i):
                 self.run_code_block(kid[1])
                 return
 
@@ -179,13 +182,20 @@ class walker_interp(interp):
 
     # Helper Functions ##################
     def auto_trigger_node_actions(self, nd, act_list):
+        already_executed = []  # handles inhereted duplicates, (overriding)
         for i in act_list.obj_list():
-            if i.access_list and self.name not in i.access_list:
+            if (
+                i.access_list
+                and self.name not in i.access_list
+                or i.name in already_executed
+            ):
                 continue
             if i.preset_in_out:
                 self.run_preset_in_out(jac_ir_to_ast(i.preset_in_out), nd, i)
             else:
                 self.call_ability(nd=nd, name=i.name, act_list=act_list)
+            if not i.preset_in_out:  # All preset in and outs get executed
+                already_executed.append(i.name)
 
     def viable_nodes(self):
         """Returns all nodes that shouldnt be ignored"""
