@@ -10,10 +10,10 @@ class file_hook(mem_hook):
     def __init__(self, filename):
         mem_hook.__init__(self)
         self.filename = filename
-        with open(filename, 'rb') as f:
+        with open(filename, "rb") as f:
             self.mem = pickle.load(f)
 
     def commit(self):
         """Write through all saves to store"""
-        with open(self.filename, 'wb') as f:
+        with open(self.filename, "wb") as f:
             pickle.dump(self.mem, f)
